/**
 * JASMINe
 * Copyright (C) 2009-2011 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StartEngineCommand.as 7876 2011-03-28 11:42:39Z danesa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.enginedashboard.command
{
  import com.adobe.cairngorm.commands.ICommand;
  import com.adobe.cairngorm.control.CairngormEvent;
  import com.adobe.cairngorm.control.CairngormEventDispatcher;

  import org.ow2.jasmine.kerneos.common.event.KerneosNotificationEvent;

  import flash.utils.getQualifiedClassName;

  import mx.rpc.IResponder;
  import mx.rpc.events.FaultEvent;

  import org.ow2.jasmine.monitoring.eos.common.controls.ServerSideException;
  import org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent;
  import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.business.IStartEngineDelegate;
  import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.event.EngineDashboardEvent;
  import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.EngineDashboardModelLocator;
  import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.domain.EngineDashboardModel;

  /**
   * Start the rule engine
   *
   * @author Julien Nicoulaud
   */
  public class StartEngineCommand implements ICommand, IResponder
  {

    // =========================================================================
    // Execution
    // =========================================================================

    /**
     * Send the event to the java side, using the business layer of the pattern
     */
    public function execute(event:CairngormEvent):void
    {
      // Retrieve the command delegate
      var delegate:IStartEngineDelegate =
        EngineDashboardModelLocator.getInstance().getStartEngineDelegate();

      // Set this object as a responder
      delegate.responder = this;

      // Retrieve the component model
      var model:EngineDashboardModel =
        EngineDashboardModelLocator.getInstance().engineDashboardModel;

      // Dispatch a notification to Kerneos
      CairngormEventDispatcher.getInstance().dispatchEvent(
        new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION + model.componentID,
          (getQualifiedClassName(this).split("::"))[1] + ": Starting the rule engine instance \"" +
          model.ruleEngineName + "\"",
          KerneosNotificationEvent.DEBUG)
      );

      // Execute a server-side method thanks to the delegate
      delegate.startEngine(model.ruleEngineName);
    }


    // =========================================================================
    // Result handling
    // =========================================================================

    /**
     * Get the result of the java side. this method is called on each event
     * returned from the Java side.
     */
    public function result(event : Object):void
    {
      // Do nothing
    }


    // =========================================================================
    // Fault handling
    // =========================================================================

    /**
     * Handle fault messages
     */
    public function fault(event : Object) : void
    {
      // Retrieve the fault event
      var faultEvent : FaultEvent = FaultEvent(event);

      // Retrieve the component model
      var model:EngineDashboardModel =
        EngineDashboardModelLocator.getInstance().engineDashboardModel;

      // Tell the view and let it handle this
      var serverSideExceptionEvent : ServerSideExceptionEvent =
        new ServerSideExceptionEvent(
          ServerSideExceptionEvent.SERVER_SIDE_EXCEPTION + model.componentID,
          new ServerSideException("Error while starting the rule engine",
            "The operation could not be performed."
            + "\n" + faultEvent.fault.faultCode
            + "\n" + faultEvent.fault.faultString,
            faultEvent.fault.getStackTrace()));
      CairngormEventDispatcher.getInstance().dispatchEvent(serverSideExceptionEvent);

      // Update the status
      CairngormEventDispatcher.getInstance().dispatchEvent(
        new EngineDashboardEvent(EngineDashboardEvent.UPDATE_ENGINE_STATUS)
      );

    }

  }
}
