/**
 * JASMINe
 * Copyright (C) 2009-2011 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: UpdateEngineStatusCommand.as 7874 2011-03-28 09:50:05Z danesa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.enginedashboard.command
{
  import com.adobe.cairngorm.commands.ICommand;
  import com.adobe.cairngorm.control.CairngormEvent;

  import mx.rpc.IResponder;
  import mx.rpc.events.FaultEvent;
  import mx.rpc.events.ResultEvent;

  import org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent;
  import org.ow2.jasmine.monitoring.eos.rules.common.vo.EngineStatusVO;
  import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.business.IUpdateEngineStatusDelegate;
  import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.EngineDashboardModelLocator;
  import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.domain.EngineDashboardModel;

  import mx.controls.Alert;
  import mx.resources.ResourceManager;

  /**
   * Update the rule engine status
   *
   * @author Julien Nicoulaud
   */
  public class UpdateEngineStatusCommand implements ICommand, IResponder
  {

    // =========================================================================
    // Execution
    // =========================================================================

    /**
     * Send the event to the java side, using the business layer of the pattern
     */
    public function execute(event:CairngormEvent):void
    {
      // Retrieve the command delegate
      var delegate:IUpdateEngineStatusDelegate =
        EngineDashboardModelLocator.getInstance().getUpdateEngineStatusDelegate();

      // Set this object as a responder
      delegate.responder = this;

      // Retrieve the component model
      var model:EngineDashboardModel =
        EngineDashboardModelLocator.getInstance().engineDashboardModel;

      // Don't dispatch a notification to Kerneos in this command,
      // it would flood the log

      // Execute a server-side method thanks to the delegate
      delegate.updateEngineStatus(model.ruleEngineName);
    }


    // =========================================================================
    // Result handling
    // =========================================================================

    /**
     * Get the result of the java side. this method is called on each event
     * returned from the Java side.
     */
    public function result(event : Object):void
    {
      // Retrieve the model
      var model:EngineDashboardModel =
        EngineDashboardModelLocator.getInstance().engineDashboardModel;

      // Store the result in the model
      model.engineStatus = (event as ResultEvent).result as EngineStatusVO;
    }


    // =========================================================================
    // Fault handling
    // =========================================================================

    /**
     * Handle fault messages
     */
    public function fault(event : Object) : void
    {
      // Retrieve the fault event
      var faultEvent : FaultEvent = FaultEvent(event);

      // Retrieve the model
      var model:EngineDashboardModel =
        EngineDashboardModelLocator.getInstance().engineDashboardModel;

      // Mark the engine status as disconnected, and store
      // informations about the connection failure.
      var engineStatus : EngineStatusVO = new EngineStatusVO();
      engineStatus.ruleEngineName = model.ruleEngineName;
      engineStatus.engineStatus = "DISCONNECTED";

      var engineDetailsSuplem = ResourceManager.getInstance().getString('commonrulesResources', 'enginedetailsUpdateError.txt')
        + "\n" + faultEvent.fault.faultCode
        + "\n" + faultEvent.fault.faultString;

      engineStatus.engineDetails = engineDetailsSuplem;

      // Store the result in the model
      model.engineStatus = (event as ResultEvent).result as EngineStatusVO;
    }

  }
}
